@@ -1,4 +1,4 @@
-// Copyright (C) 2001,2002,2004 Federico Montesino Pouzols <fedemp@altern.org>.
+// Copyright (C) 2001,2002,2004,2005 Federico Montesino Pouzols <fedemp@altern.org>.
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -45,6 +45,7 @@
 #define CCXX_RTP_OQUEUE_H_
 
 #include <ccrtp/queuebase.h>
+#include <list> // TODO: minimal std::list template
 
 #ifdef	CCXX_NAMESPACES
 namespace ost {
@@ -67,6 +68,7 @@ class __EXPORT DestinationListHandler
 {
 protected:
 	struct TransportAddress;
+	std::list<TransportAddress*> destList;
 
 public:
 	DestinationListHandler();
@@ -77,10 +79,10 @@ public:
 	 * Get whether there is only a destination in the list.
 	 **/
 	inline bool isSingleDestination() const
-	{ return (destinationCounter == 1); }
+	{ return (1 == destList.size()); }
 
 	inline TransportAddress* getFirstDestination() const
-	{ return firstDestination; }
+	{ return destList.front(); }
 
 	inline void lockDestinationList() const
 	{ destinationLock.readLock(); }
@@ -110,15 +112,9 @@ protected:
 	{ 
 		TransportAddress(InetAddress na, tpport_t dtp, tpport_t ctp) :
 			networkAddress(na), dataTransportPort(dtp), 
-			controlTransportPort(ctp), next(NULL)
+			controlTransportPort(ctp)
 		{  }
 
-		inline TransportAddress* getNext()
-		{ return next; }
-
-		inline void setNext(TransportAddress* nc)
-		{ next = nc; }
-
 		inline const InetAddress& getNetworkAddress() const
 		{ return networkAddress; }
 
@@ -130,12 +126,9 @@ protected:
 
 		InetAddress networkAddress;
 		tpport_t dataTransportPort, controlTransportPort;
-		TransportAddress* next;
 	};
 
 private:
-	uint8 destinationCounter;
-	TransportAddress* firstDestination, * lastDestination;
 	mutable ThreadLock destinationLock;
 };
 
@@ -207,6 +200,15 @@ public:
 	 **/
 	void
 	putData(uint32 stamp, const unsigned char* data = NULL, size_t len = 0);
+	
+	/**
+	 * Set padding. All outgoing packets will be transparently
+	 * padded to a multiple of paddinglen.
+	 *
+	 * @param paddinglen pad packets to a length multiple of paddinglen.
+	 **/
+	void setPadding(uint8 paddinglen)
+	{ sendInfo.paddinglen = paddinglen; }
 
 	/**
 	 * Set marker bit for the packet in which the next data
@@ -405,6 +407,8 @@ private:
 		uint32 sendSources[16];
 		// how many CSRCs to send.
 		uint16 sendCC;
+		// pad packets to a paddinglen multiple
+		uint8 paddinglen;
 		// This flags tells whether to set the bit M in the
 		// RTP fixed header of the packet in which the next
 		// provided data will be sent.
